slaveLatency property

int? slaveLatency
final

The peripheral latency (slave latency) in number of connection events.

The number of consecutive connection events the peripheral is allowed to skip without losing the connection. Zero means the peripheral must respond to every event.

Implementation

final int? slaveLatency;