BleConnectionState enum

Enumeration representing the possible connection states between a Bluetooth peripheral and the host platform.

  • connected: The Bluetooth peripheral is successfully connected.
  • disconnected: The Bluetooth peripheral is disconnected from the host device.
  • connecting: A connection between the peripheral and the host device is in the process of being established.
  • disconnecting: The peripheral and the host device are in the process of disconnecting.
  • unknown: The connection, or lack thereof, between the peripheral and the host device is in an unknown state.
Inheritance
Available extensions

Values

connected → const BleConnectionState

The Bluetooth peripheral is successfully connected.

const BleConnectionState('connected')
disconnected → const BleConnectionState

The Bluetooth peripheral is disconnected from the host device.

const BleConnectionState('disconnected')
connecting → const BleConnectionState

A connection between the peripheral and the host device is in the process of being established.

const BleConnectionState('connecting')
disconnecting → const BleConnectionState

The peripheral and the host device are in the process of disconnecting.

const BleConnectionState('disconnecting')
unknown → const BleConnectionState

The connection, or lack thereof, between the peripheral and the host device is in an unknown state.

const BleConnectionState('unknown')

Properties

hashCode → int
The hash code for this object.
no setterinherited
identifier → String
A String identifier for each BleConnectionState value.
final
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<BleConnectionState>
A constant List of the values in this enum, in order of their declaration.