legacyMode property

bool? legacyMode
final

Whether to restrict scanning to legacy BLE advertising PDUs.

When set to false on Android 8 (API 26) and above, the scanner operates in non-legacy mode and can receive extended advertising PDUs. This is required for devices that send additional data in a scan response packet. When this field is null, the Android side defaults to false (non-legacy) so that scan response data is always included when the hardware supports it.

This field has no effect on iOS or older Android versions.

Implementation

final bool? legacyMode;