stopScan method

Future<void> stopScan()

Asks the platform to stop scanning for Bluetooth devices.

Returns a Future that completes when the scan has been stopped.

Implementation

Future<void> stopScan() {
  return _platform.stopScan();
}